@@ -86,6 +86,10 @@ impl Client {
             "Creating new session with genesis key: {} ...",
             hex::encode(config.genesis_key.to_bytes())
         );
+
+        // Session wait time. We want this relative to query timeout for now. Which defaults to 90s
+        let standard_wait = config.query_timeout / 10;
+
         // Create a session with the network
         let session = Session::new(
             client_pk,
@@ -93,6 +97,7 @@ impl Client {
             config.qp2p,
             err_sender,
             config.local_addr,
+            standard_wait,
         )
         .await?;
 
